@@ -246,6 +246,7 @@ class Resource:
         BATCH = "batch"
         CDI_KUBEVIRT_IO = "cdi.kubevirt.io"
         CLONE_KUBEVIRT_IO = "clone.kubevirt.io"
+        CLUSTER_OPEN_CLUSTER_MANAGEMENT_IO = "cluster.open-cluster-management.io"
         CONFIG_OPENSHIFT_IO = "config.openshift.io"
         CONSOLE_OPENSHIFT_IO = "console.openshift.io"
         COORDINATION_K8S_IO = "coordination.k8s.io"
@@ -281,7 +282,11 @@ class Resource:
         NODE_LABELLER_KUBEVIRT_IO = "node-labeller.kubevirt.io"
         NMSTATE_IO = "nmstate.io"
         NODEMAINTENANCE_KUBEVIRT_IO = "nodemaintenance.kubevirt.io"
+        OBSERVABILITY_OPEN_CLUSTER_MANAGEMENT_IO = (
+            "observability.open-cluster-management.io"
+        )
         OCS_OPENSHIFT_IO = "ocs.openshift.io"
+        OPERATOR_OPEN_CLUSTER_MANAGEMENT_IO = "operator.open-cluster-management.io"
         OPERATOR_OPENSHIFT_IO = "operator.openshift.io"
         OPERATORS_COREOS_COM = "operators.coreos.com"
         OPERATORS_OPENSHIFT_IO = "operators.openshift.io"
