@@ -1,5 +1,5 @@
 from ocp_resources.resource import NamespacedResource
-from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
+from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler, TimeoutWatch
 
 
 class SriovNetworkNodeState(NamespacedResource):
@@ -30,8 +30,17 @@ class SriovNetworkNodeState(NamespacedResource):
             f"Wait for {self.kind} {self.name} status to be {wanted_status}"
         )
         try:
+            timeout_watcher = TimeoutWatch(timeout=timeout)
             for sample in TimeoutSampler(
                 wait_timeout=timeout,
+                sleep=1,
+                func=lambda: self.exists,
+            ):
+                if sample:
+                    break
+
+            for sample in TimeoutSampler(
+                wait_timeout=timeout_watcher.remaining_time(),
                 sleep=3,
                 func=lambda: self.instance.status.syncStatus,
             ):
